==> hinemos_agent-4.0.3_rhel4_32.tar.gz: com/clustercontrol/ws/monitor/PingCheckInfo.java <==

package com.clustercontrol.ws.monitor;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for pingCheckInfo complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="pingCheckInfo">
 *   &lt;complexContent>
 *     &lt;extension base="{http://monitor.ws.clustercontrol.com}monitorCheckInfo">
 *       &lt;sequence>
 *         &lt;element name="runCount" type="{http://www.w3.org/2001/XMLSchema}int" minOccurs="0"/>
 *         &lt;element name="runInterval" type="{http://www.w3.org/2001/XMLSchema}int" minOccurs="0"/>
 *         &lt;element name="timeout" type="{http://www.w3.org/2001/XMLSchema}int" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "pingCheckInfo", propOrder = {
    "runCount",
    "runInterval",
    "timeout"
})
public class PingCheckInfo
    extends MonitorCheckInfo
{

    protected Integer runCount;
    protected Integer runInterval;
    protected Integer timeout;

    /**
     * Gets the value of the runCount property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getRunCount() {
        return runCount;
    }

    /**
     * Sets the value of the runCount property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setRunCount(Integer value) {
        this.runCount = value;
    }

    /**
     * Gets the value of the runInterval property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getRunInterval() {
        return runInterval;
    }

    /**
     * Sets the value of the runInterval property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setRunInterval(Integer value) {
        this.runInterval = value;
    }

    /**
     * Gets the value of the timeout property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getTimeout() {
        return timeout;
    }

    /**
     * Sets the value of the timeout property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setTimeout(Integer value) {
        this.timeout = value;
    }

}

==> hinemos_agent-4.1.3_rhel4_32.tar.gz: com/clustercontrol/ws/monitor/PingCheckInfo.java <==

package com.clustercontrol.ws.monitor;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>pingCheckInfo complex typeのJavaクラス。
 * 
 * <p>次のスキーマ・フラグメントは、このクラス内に含まれる予期されるコンテンツを指定します。
 * 
 * <pre>
 * &lt;complexType name="pingCheckInfo">
 *   &lt;complexContent>
 *     &lt;extension base="{http://monitor.ws.clustercontrol.com}monitorCheckInfo">
 *       &lt;sequence>
 *         &lt;element name="runCount" type="{http://www.w3.org/2001/XMLSchema}int" minOccurs="0"/>
 *         &lt;element name="runInterval" type="{http://www.w3.org/2001/XMLSchema}int" minOccurs="0"/>
 *         &lt;element name="timeout" type="{http://www.w3.org/2001/XMLSchema}int" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "pingCheckInfo", propOrder = {
    "runCount",
    "runInterval",
    "timeout"
})
public class PingCheckInfo
    extends MonitorCheckInfo
{

    protected Integer runCount;
    protected Integer runInterval;
    protected Integer timeout;

    /**
     * runCountプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getRunCount() {
        return runCount;
    }

    /**
     * runCountプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setRunCount(Integer value) {
        this.runCount = value;
    }

    /**
     * runIntervalプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getRunInterval() {
        return runInterval;
    }

    /**
     * runIntervalプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setRunInterval(Integer value) {
        this.runInterval = value;
    }

    /**
     * timeoutプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getTimeout() {
        return timeout;
    }

    /**
     * timeoutプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setTimeout(Integer value) {
        this.timeout = value;
    }

}
